#
# spec file for package vegeta
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           vegeta
Version:        12.12.0
Release:        1.1
Summary:        HTTP load testing tool and library
License:        MIT
URL:            https://github.com/tsenart/vegeta
Source:         vegeta-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22

%description
Vegeta is a versatile HTTP load testing tool built out of a need to drill HTTP
services with a constant request rate.

Features:

* Usable as a command line tool and a Go library.
* CLI designed with UNIX composability in mind.
* Avoids nasty Coordinated Omission.
* Extensive reporting functionality.
* Simple to use for distributed load testing.
* Easy to install and run (static binary, package managers, etc).

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X main.Version=%{version} -X main.Commit=${COMMIT_HASH} -X main.Date=$BUILD_DATE" \
   -o bin/vegeta

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Sat Aug 24 2024 jgwang@suse.com
- Update to version 12.12.0:
  * lib,cmd: add Dan as contributor for -connect-to
  * lib,cmd: add -connect-to flag
* Mon Jul 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 12.11.3:
  * lib: use fixed IP selection function
* Sat Jul 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 12.11.2:
  * lib: fix IP selection in DNS caching
  * lib/prom: fix broken test after dep upgrade
  * more dep updates
  * update deps
  * update ci go version to 1.22
  * update go version to go 1.22
  * .github/workflows/ci.yml: update outdated actions that github
    warns need updating
  * build(deps): bump github.com/google/go-cmp from 0.5.9 to 0.6.0
  * build(deps): bump github.com/prometheus/client_golang
  * build(deps): bump github.com/prometheus/prometheus from 0.47.0
    to 0.47.2
* Sat Jan 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package vegeta: HTTP load testing tool and library
